/*
 * voicechat - Voice chat via TCP/IP
 * Copyright 1995 Riku Saikkonen (rjs@spider.compart.fi)
 *
 * Voicechat is free software, distributed under the terms of the GNU
 * General Public License version 2, and comes with ABSOLUTELY NO WARRANTY;
 * for details, see the file README distributed with the program.
 */

#include <stdio.h>
#include <unistd.h>
#include <netdb.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <arpa/inet.h> /* inet_addr() */
#include <linux/in.h>
#include "voicechat.h"

int netfd=-1;

void open_net_connect(char *hostname, int port)
{
  struct sockaddr_in sin;
  struct hostent *hent;

  netfd=socket(AF_INET,SOCK_STREAM,IPPROTO_TCP);
  if (netfd==-1) fatals("opening network socket");

  sin.sin_family=AF_INET;
  sin.sin_port=htons(port);

  if ((sin.sin_addr.s_addr=inet_addr(hostname))==-1) /* Not an IP number */
  {
    hent=gethostbyname(hostname);
    if (hent==NULL) fatal("resolving host name");
    memcpy(&sin.sin_addr,hent->h_addr_list[0],sizeof(sin.sin_addr));
  }

  if (connect(netfd,(struct sockaddr *)&sin,sizeof(sin))==-1)
    fatals("connecting to remote");
}

void open_net_listen(int port)
{
  struct sockaddr_in sin;
  int fd,i;

  fd=socket(AF_INET,SOCK_STREAM,IPPROTO_TCP);
  if (fd==-1) fatals("opening network socket");
  
  sin.sin_family=AF_INET;
  sin.sin_addr.s_addr=INADDR_ANY;
  sin.sin_port=htons(port);

  if (bind(fd,(struct sockaddr *)&sin,sizeof(sin))==-1)
    fatals("binding network socket");

  if (listen(fd,1)==-1) fatals("listening on network socket");

  i=sizeof(struct sockaddr_in);
  if ((netfd=accept(fd,(struct sockaddr *)&sin,&i))==-1)
    fatals("accepting a connection");

  close(fd); /* XXX Don't always accept first connection */
}

void close_net(void)
{
  if (netfd>=0) close(netfd);
}
